pub struct Serializer<B: BufMut> { /* private fields */ }Expand description
A structure for serializing Rust values into a memcomparable bytes.
Implementations
Sourceimpl<B: BufMut> Serializer<B>
impl<B: BufMut> Serializer<B>
Sourcepub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Unwrap the inner buffer from the Serializer.
Sourcepub fn set_reverse(&mut self, reverse: bool)
pub fn set_reverse(&mut self, reverse: bool)
Set whether data is serialized in reverse order.
Sourceimpl<B: BufMut> Serializer<B>
impl<B: BufMut> Serializer<B>
Sourcepub fn serialize_decimal(&mut self, decimal: Decimal) -> Result<()>
Available on crate feature decimal only.
pub fn serialize_decimal(&mut self, decimal: Decimal) -> Result<()>
decimal only.Serialize a decimal value.
The encoding format follows SQLite: https://sqlite.org/src4/doc/trunk/www/key_encoding.wiki
except that NaN is considered larger than +Infinity, to be consistent with f32 and f64.
Example
use memcomparable::Decimal;
let d1 = Decimal::Normalized("12.34".parse().unwrap());
let d2 = Decimal::Inf;
let mut ser = memcomparable::Serializer::new(vec![]);
ser.serialize_decimal(d1.into()).unwrap();
ser.serialize_decimal(d2).unwrap();Trait Implementations
Sourceimpl<'a, B: BufMut> SerializeMap for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeMap for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeSeq for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeSeq for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeStruct for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeStruct for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeStructVariant for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeStructVariant for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeTuple for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeTuple for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeTupleStruct for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeTupleStruct for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> SerializeTupleVariant for &'a mut Serializer<B>
impl<'a, B: BufMut> SerializeTupleVariant for &'a mut Serializer<B>
Sourceimpl<'a, B: BufMut> Serializer for &'a mut Serializer<B>
impl<'a, B: BufMut> Serializer for &'a mut Serializer<B>
Sourcetype Ok = ()
type Ok = ()
The output type produced by this
Serializer during successful
serialization. Most serializers that produce text or binary output
should set Ok = () and serialize into an io::Write or buffer
contained within the Serializer instance. Serializers that build
in-memory data structures may be simplified by using Ok to propagate
the data structure around.Sourcetype SerializeMap = &'a mut Serializer<B>
type SerializeMap = &'a mut Serializer<B>
Type returned from
serialize_map for serializing the content of the
map.Sourcetype SerializeSeq = &'a mut Serializer<B>
type SerializeSeq = &'a mut Serializer<B>
Type returned from
serialize_seq for serializing the content of the
sequence.Sourcetype SerializeStruct = &'a mut Serializer<B>
type SerializeStruct = &'a mut Serializer<B>
Type returned from
serialize_struct for serializing the content of
the struct.Sourcetype SerializeStructVariant = &'a mut Serializer<B>
type SerializeStructVariant = &'a mut Serializer<B>
Type returned from
serialize_struct_variant for serializing the
content of the struct variant.Sourcetype SerializeTuple = &'a mut Serializer<B>
type SerializeTuple = &'a mut Serializer<B>
Type returned from
serialize_tuple for serializing the content of
the tuple.Sourcetype SerializeTupleStruct = &'a mut Serializer<B>
type SerializeTupleStruct = &'a mut Serializer<B>
Type returned from
serialize_tuple_struct for serializing the
content of the tuple struct.Sourcetype SerializeTupleVariant = &'a mut Serializer<B>
type SerializeTupleVariant = &'a mut Serializer<B>
Type returned from
serialize_tuple_variant for serializing the
content of the tuple variant.Sourcefn serialize_bytes(self, v: &[u8]) -> Result<()>
fn serialize_bytes(self, v: &[u8]) -> Result<()>
Serialize a chunk of raw byte data. Read more
Sourcefn serialize_unit_variant(
self,
_name: &'static str,
variant_index: u32,
_variant: &'static str,
) -> Result<()>
fn serialize_unit_variant( self, _name: &'static str, variant_index: u32, _variant: &'static str, ) -> Result<()>
Sourcefn serialize_newtype_struct<T>(
self,
_name: &'static str,
value: &T,
) -> Result<()>
fn serialize_newtype_struct<T>( self, _name: &'static str, value: &T, ) -> Result<()>
Serialize a newtype struct like
struct Millimeters(u8). Read moreSourcefn serialize_newtype_variant<T>(
self,
_name: &'static str,
variant_index: u32,
_variant: &'static str,
value: &T,
) -> Result<()>
fn serialize_newtype_variant<T>( self, _name: &'static str, variant_index: u32, _variant: &'static str, value: &T, ) -> Result<()>
Sourcefn serialize_seq(self, _len: Option<usize>) -> Result<Self::SerializeSeq>
fn serialize_seq(self, _len: Option<usize>) -> Result<Self::SerializeSeq>
Begin to serialize a variably sized sequence. This call must be
followed by zero or more calls to
serialize_element, then a call to
end. Read moreSourcefn serialize_tuple(self, _len: usize) -> Result<Self::SerializeTuple>
fn serialize_tuple(self, _len: usize) -> Result<Self::SerializeTuple>
Begin to serialize a statically sized sequence whose length will be
known at deserialization time without looking at the serialized data.
This call must be followed by zero or more calls to
serialize_element,
then a call to end. Read moreSourcefn serialize_tuple_struct(
self,
_name: &'static str,
_len: usize,
) -> Result<Self::SerializeTupleStruct>
fn serialize_tuple_struct( self, _name: &'static str, _len: usize, ) -> Result<Self::SerializeTupleStruct>
Begin to serialize a tuple struct like
struct Rgb(u8, u8, u8). This
call must be followed by zero or more calls to serialize_field, then a
call to end. Read moreSourcefn serialize_tuple_variant(
self,
_name: &'static str,
variant_index: u32,
_variant: &'static str,
_len: usize,
) -> Result<Self::SerializeTupleVariant>
fn serialize_tuple_variant( self, _name: &'static str, variant_index: u32, _variant: &'static str, _len: usize, ) -> Result<Self::SerializeTupleVariant>
Begin to serialize a tuple variant like
E::T in enum E { T(u8, u8) }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read moreSourcefn serialize_map(self, _len: Option<usize>) -> Result<Self::SerializeMap>
fn serialize_map(self, _len: Option<usize>) -> Result<Self::SerializeMap>
Begin to serialize a map. This call must be followed by zero or more
calls to
serialize_key and serialize_value, then a call to end. Read moreSourcefn serialize_struct(
self,
_name: &'static str,
_len: usize,
) -> Result<Self::SerializeStruct>
fn serialize_struct( self, _name: &'static str, _len: usize, ) -> Result<Self::SerializeStruct>
Begin to serialize a struct like
struct Rgb { r: u8, g: u8, b: u8 }.
This call must be followed by zero or more calls to serialize_field,
then a call to end. Read moreSourcefn serialize_struct_variant(
self,
_name: &'static str,
variant_index: u32,
_variant: &'static str,
_len: usize,
) -> Result<Self::SerializeStructVariant>
fn serialize_struct_variant( self, _name: &'static str, variant_index: u32, _variant: &'static str, _len: usize, ) -> Result<Self::SerializeStructVariant>
Begin to serialize a struct variant like
E::S in enum E { S { r: u8, g: u8, b: u8 } }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read moreSourcefn is_human_readable(&self) -> bool
fn is_human_readable(&self) -> bool
Determine whether
Serialize implementations should serialize in
human-readable form. Read moreSourcefn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error>
fn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error>
Collect an iterator as a sequence. Read more